@@ -69,9 +69,7 @@ class SoozAccess(object):
         content = {"name": name}
 
         try:
-            r = self.session.post(
-                f"{SoozAccess.host}/enterprises", json=content
-            )
+            r = self.session.post(f"{SoozAccess.host}/enterprises", json=content)
             r.raise_for_status()
         except HTTPError as e:
             pass
@@ -88,7 +86,9 @@ class SoozAccess(object):
         content = {}
 
         try:
-            r = self.session.get(f"{SoozAccess.host}/enterprises/{enterprise_id}/factors")
+            r = self.session.get(
+                f"{SoozAccess.host}/enterprises/{enterprise_id}/factors"
+            )
             r.raise_for_status()
         except HTTPError as e:
             pass
@@ -100,7 +100,7 @@ class SoozAccess(object):
         return content, r
 
     def put_entreprise_factors(self, enterprise: int):
-        """Purge and recreate selected factors of an enterprise."""        
+        """Purge and recreate selected factors of an enterprise."""
         raise NotImplementedError("Not implemented yet")
 
     # FACTORS
@@ -227,7 +227,7 @@ class SoozAccess(object):
 
     def post_group(self, name: str, description: str) -> Tuple[dict, Response]:
         """Create a group in the enterprise of the user."""
-        if name in [g["group"]["name"] for g in self.get_groups()[0]]:
+        if name in [g["group"]["name"] for g in self.get_user_groups()[0]]:
             Logger.write("Group already exists")
             return None, None
 
@@ -248,12 +248,13 @@ class SoozAccess(object):
     def put_group(self, group: int, name: str, description: str):
         """Update a group (requires the user to be admin of the group)."""
 
-        content = {"name": name,"description": description,}
+        content = {
+            "name": name,
+            "description": description,
+        }
 
         try:
-            r = self.session.put(
-                f"{SoozAccess.host}/groups/{group}", json=content
-            )
+            r = self.session.put(f"{SoozAccess.host}/groups/{group}", json=content)
             r.raise_for_status()
         except HTTPError as e:
             pass
@@ -292,7 +293,7 @@ class SoozAccess(object):
             content = json.loads(r.content.decode("utf-8"))
         finally:
             self.show_status("    Get Levels", r)
-        
+
         return content, r
 
     # RESPONSE OPTIONS
@@ -363,13 +364,15 @@ class SoozAccess(object):
 
         return content, r
 
-    def get_all_responses(self, since: str, to:str) -> Tuple[dict, Response]:
+    def get_all_responses(self, since: str, to: str) -> Tuple[dict, Response]:
         """Get all responses of the user for a specific period of time."""
 
         content = {}
 
         try:
-            r = self.session.get(f"{SoozAccess.host}/oneshot/responses/since/{since}/to/{to}")
+            r = self.session.get(
+                f"{SoozAccess.host}/oneshot/responses/since/{since}/to/{to}"
+            )
             r.raise_for_status()
         except HTTPError as e:
             pass
@@ -396,7 +399,7 @@ class SoozAccess(object):
             content = json.loads(r.content.decode("utf-8"))
         finally:
             self.show_status("    Get Factor Responses", r)
-            
+
         return content, r
 
     def put_response(
@@ -439,7 +442,6 @@ class SoozAccess(object):
 
         return {}, r
 
-
     def get_all_themes_responses(self):
         """Get responses of today to all themes for the user."""
 
@@ -457,7 +459,6 @@ class SoozAccess(object):
 
         return content, r
 
-
     def get_theme_responses(self, theme: int):
         """Get todays response of the user for given theme (only used for the environment category question)."""
 
@@ -494,7 +495,6 @@ class SoozAccess(object):
     ):
         """Returns the number of responses per responseId for one factor."""
 
-
         raise NotImplementedError("Not implemented yet")
 
     def get_stats_days(
@@ -644,7 +644,7 @@ class SoozAccess(object):
 
     # OTHER
     def remove_groups(self):
-        for g in self.get_groups()[0]:
+        for g in self.get_user_groups()[0]:
             self.delete_group(g["group"]["id"])
 
     def show_status(self, text: str, r: Response):
